==> react-d3-0.1.7.tgz: package/scatterchart.js <==
'use strict';

var React = require('react');
var d3 = require('d3');
var common = require('./common');
var Chart = common.Chart;
var XAxis = common.XAxis;
var YAxis = common.YAxis;
var Voronoi = common.Voronoi;
var EventEmitter = require('events').EventEmitter;
var pubsub = exports.pubsub = new EventEmitter();
var utils = require('./utils');

var Circle = React.createClass({displayName: 'Circle',

  propTypes: {
    id: React.PropTypes.string,
    cx: React.PropTypes.number,
    cy: React.PropTypes.number,
    r: React.PropTypes.number,
    fill: React.PropTypes.string,
    stroke: React.PropTypes.string,
    strokeWidth: React.PropTypes.number,
    strokeOpacity: React.PropTypes.number,
    hoverAnimation: React.PropTypes.bool
  },

  getDefaultProps: function() {
    return {
      fill: '#1f77b4'
    };
  },

  getInitialState: function() {
    // state for animation usage
    return {
      circleRadius: this.props.r,
      circleColor: this.props.fill
    };
  },

  componentDidMount: function() {
    pubsub.on('animateCircle', this._animateCircle);
    pubsub.on('restoreCircle', this._restoreCircle);
  },

  componentWillUnmount: function() {
    pubsub.removeListener('animateCircle', this._animateCircle);
    pubsub.removeListener('restoreCircle', this._restoreCircle);
  },

  render: function() {
    return (
      React.createElement("circle", {
        fill: this.state.circleColor, 
        cx: this.props.cx, 
        cy: this.props.cy, 
        r: this.state.circleRadius, 
        id: this.props.id}
      )
    );
  },

  _animateCircle: function(id) {
    if (this.props.id === id) {
      this.setState({ 
        circleRadius: this.state.circleRadius * ( 5 / 4 ),
        circleColor: utils.shade(this.props.fill, -0.2)
      });
    }
  },

  _restoreCircle: function(id) {
    if (this.props.id === id) {
      this.setState({ 
        circleRadius: this.state.circleRadius * ( 4 / 5 ),
        circleColor: this.props.fill
      });
    }
  }

});

var DataSeries = exports.DataSeries = React.createClass({displayName: 'DataSeries',

  propTypes: {
    data: React.PropTypes.array,
    color: React.PropTypes.string
  },

  getDefaultProps: function() {
    return {
      data: [],
      color: '#fff'
    };
  },

  render: function() {

    var circles = this.props.data.map(function(point, i) {
      return (React.createElement(Circle, {cx: this.props.xScale(point.x), cy: this.props.yScale(point.y), r: this.props.pointRadius, fill: this.props.color, key: this.props.seriesName + i, id: this.props.seriesName + '-' + i}));
    }.bind(this));

    return (
      React.createElement("g", null, 
        circles
      )
    );
  }

});


var ScatterChart = exports.ScatterChart = React.createClass({displayName: 'ScatterChart',

  propTypes: {
    margins: React.PropTypes.object,
    legendOffset: React.PropTypes.number,
    titleOffset: React.PropTypes.number,
    pointRadius: React.PropTypes.number,
    yHideOrigin: React.PropTypes.bool,
    xHideOrigin: React.PropTypes.bool,
    width: React.PropTypes.number,
    height: React.PropTypes.number,
    axesColor: React.PropTypes.string,
    title: React.PropTypes.string,
    colors: React.PropTypes.func,
    legend: React.PropTypes.bool,
    hoverAnimation: React.PropTypes.bool,
  },

  getDefaultProps: function() {
    return {
      margins: {top: 20, right: 30, bottom: 30, left: 30},
      legendOffset: 120,
      titleOffset: 56,
      pointRadius: 3,
      width: 400,
      height: 200,
      axesColor: '#000',
      title: '',
      colors: d3.scale.category20c(),
      hoverAnimation: true
    };
  },

  _calculateScales: utils.calculateScales,

  render: function() {

    var props = this.props;

    // Calculate inner chart dimensions
    var chartWidth, chartHeight;

    chartWidth = props.width - props.margins.left - props.margins.right;
    chartHeight = props.height - props.margins.top - props.margins.bottom;

    if (props.legend) {
      chartWidth = chartWidth - props.legendOffset;
    }

    if (props.title) {
      chartHeight = chartHeight - props.titleOffset;
    }

    var allData = utils.concatData(props.data), 
        allValues = allData.allValues,
        xValues = allData.xValues,
        yValues = allData.yValues;

    // Set pubsub max listeners to total number of nodes to be created
    pubsub.setMaxListeners(xValues.length + yValues.length);

    var scales = this._calculateScales(chartWidth, chartHeight, xValues, yValues);

    var trans = "translate(" + props.margins.left + "," + props.margins.top + ")";

    var dataSeriesArray = Object.keys(props.data).map( (seriesName, idx) => {
      return (
          React.createElement(DataSeries, {
            xScale: scales.xScale, 
            yScale: scales.yScale, 
            seriesName: seriesName, 
            data: props.data[seriesName], 
            width: chartWidth, 
            height: chartHeight, 
            color: props.colors(idx), 
            pointRadius: props.pointRadius, 
            key: seriesName, 
            hoverAnimation: props.hoverAnimation}
          )
      );
    });

    return (
      React.createElement(Chart, {width: props.width, height: props.height, title: props.title}, 
        React.createElement("g", {transform: trans}, 
          React.createElement(Voronoi, {
            pubsub: pubsub, 
            data: allValues, 
            yScale: scales.yScale, 
            xScale: scales.xScale, 
            width: chartWidth, 
            height: chartHeight}
          ), 
          dataSeriesArray, 
          React.createElement(YAxis, {
            yAxisClassName: "scatter y axis", 
            yScale: scales.yScale, 
            yHideOrigin: props.yHideOrigin, 
            margins: props.margins, 
            yAxisTickCount: props.yAxisTickCount, 
            width: chartWidth, 
            height: chartHeight, 
            stroke: props.axesColor}
          ), 
          React.createElement(XAxis, {
            xAxisClassName: "scatter x axis", 
            strokeWidth: "1", 
            xHideOrigin: props.xHideOrigin, 
            xScale: scales.xScale, 
            data: props.data, 
            margins: props.margins, 
            width: chartWidth, 
            height: chartHeight, 
            stroke: props.axesColor}
          )
        )
      )
    );
  }

});

==> react-d3-0.2.0.tgz: package/scatterchart.js <==
'use strict';

var React = require('react');
var d3 = require('d3');
var common = require('./common');
var Chart = common.Chart;
var XAxis = common.XAxis;
var YAxis = common.YAxis;
var Voronoi = common.Voronoi;
var EventEmitter = require('events').EventEmitter;
var pubsub = exports.pubsub = new EventEmitter();
var utils = require('./utils');

var Circle = React.createClass({displayName: "Circle",

  propTypes: {
    id: React.PropTypes.string,
    cx: React.PropTypes.number,
    cy: React.PropTypes.number,
    r: React.PropTypes.number,
    fill: React.PropTypes.string,
    stroke: React.PropTypes.string,
    strokeWidth: React.PropTypes.number,
    strokeOpacity: React.PropTypes.number,
    hoverAnimation: React.PropTypes.bool
  },

  getDefaultProps: function() {
    return {
      fill: '#1f77b4'
    };
  },

  getInitialState: function() {
    // state for animation usage
    return {
      circleRadius: this.props.r,
      circleColor: this.props.fill
    };
  },

  componentDidMount: function() {
    pubsub.on('animate', this._animateCircle);
    pubsub.on('restore', this._restoreCircle);
  },

  componentWillUnmount: function() {
    pubsub.removeListener('animate', this._animateCircle);
    pubsub.removeListener('restore', this._restoreCircle);
  },

  render: function() {
    return (
      React.createElement("circle", {
        fill: this.state.circleColor, 
        cx: this.props.cx, 
        cy: this.props.cy, 
        r: this.state.circleRadius, 
        id: this.props.id}
      )
    );
  },

  _animateCircle: function(id) {
    if (this.props.id === id) {
      this.setState({ 
        circleRadius: this.state.circleRadius * ( 5 / 4 ),
        circleColor: utils.shade(this.props.fill, -0.2)
      });
    }
  },

  _restoreCircle: function(id) {
    if (this.props.id === id) {
      this.setState({ 
        circleRadius: this.props.r,
        circleColor: this.props.fill
      });
    }
  }

});

var DataSeries = exports.DataSeries = React.createClass({displayName: "DataSeries",

  propTypes: {
    data: React.PropTypes.array,
    color: React.PropTypes.string,
    xAccessor: React.PropTypes.func,
    yAccessor: React.PropTypes.func
  },

  getDefaultProps: function() {
    return {
      data: [],
      color: '#fff',
      xAccessor: function(d)  {return d.x;},
      yAccessor: function(d)  {return d.y;}
    };
  },

  render: function() {

    var props = this.props;

    var circles = props.data.map(function(point, i) {

      var xAccessor = props.xAccessor,
          yAccessor = props.yAccessor,
          cx, cy;
      if (Object.prototype.toString.call(xAccessor(point)) === '[object Date]') {
        cx = props.xScale(xAccessor(point).getTime());
      } else {
        cx = props.xScale(xAccessor(point));
      }
      if (Object.prototype.toString.call(yAccessor(point)) === '[object Date]') {
        cy = props.yScale(yAccessor(point).getTime());
      } else {
        cy = props.yScale(yAccessor(point));
      }

      return (React.createElement(Circle, {
        cx: cx, 
        cy: cy, 
        r: props.pointRadius, 
        fill: props.color, 
        key: props.seriesName + i, 
        id: props.seriesName + '-' + i}
      ));
    }.bind(this));

    return (
      React.createElement("g", null, 
        circles
      )
    );
  }

});


var ScatterChart = exports.ScatterChart = React.createClass({displayName: "ScatterChart",

  propTypes: {
    data: React.PropTypes.oneOfType([
      React.PropTypes.array,
      React.PropTypes.object
    ]),
    margins: React.PropTypes.object,
    legendOffset: React.PropTypes.number,
    pointRadius: React.PropTypes.number,
    yHideOrigin: React.PropTypes.bool,
    xHideOrigin: React.PropTypes.bool,
    width: React.PropTypes.number,
    height: React.PropTypes.number,
    axesColor: React.PropTypes.string,
    title: React.PropTypes.string,
    colors: React.PropTypes.func,
    legend: React.PropTypes.bool,
    hoverAnimation: React.PropTypes.bool,
    xAccessor: React.PropTypes.func,
    yAccessor: React.PropTypes.func
 },

  getDefaultProps: function() {
    return {
      data: [],
      margins: {top: 20, right: 30, bottom: 30, left: 30},
      legendOffset: 120,
      legend: false,
      pointRadius: 3,
      width: 400,
      height: 200,
      axesColor: '#000',
      title: '',
      colors: d3.scale.category20c(),
      hoverAnimation: true,
      xAccessor: function(d)  {return d.x;},
      yAccessor: function(d)  {return d.y;}
    };
  },

  _calculateScales: utils.calculateScales,

  render: function() {

    var props = this.props;

    if (this.props.data && this.props.data.length < 1) {
      return React.createElement("g", null);
    }

    // Calculate inner chart dimensions
    var chartWidth, chartHeight;

    chartWidth = props.width - props.margins.left - props.margins.right;
    chartHeight = props.height - props.margins.top - props.margins.bottom;

    if (props.legend) {
      chartWidth = chartWidth - props.legendOffset;
    }

    if (!Array.isArray(props.data)) {
      props.data = [props.data];
    }

    // Returns an object of flattened allValues, xValues, and yValues
    var flattenedData = utils.flattenData(props.data, props.xAccessor, props.yAccessor);

    var allValues = flattenedData.allValues,
        xValues = flattenedData.xValues,
        yValues = flattenedData.yValues;

    // Set pubsub max listeners to total number of nodes to be created
    pubsub.setMaxListeners(xValues.length + yValues.length);

    var scales = this._calculateScales(chartWidth, chartHeight, xValues, yValues);

    var trans = "translate(" + props.margins.left + "," + props.margins.top + ")";

    var dataSeriesArray = props.data.map( function(series, idx)  {
      return (
          React.createElement(DataSeries, {
            xScale: scales.xScale, 
            yScale: scales.yScale, 
            seriesName: series.name, 
            data: series.values, 
            width: chartWidth, 
            height: chartHeight, 
            color: props.colors(idx), 
            pointRadius: props.pointRadius, 
            key: series.name, 
            hoverAnimation: props.hoverAnimation, 
            xAccessor: props.xAccessor, 
            yAccessor: props.yAccessor}
          )
      );
    });

    return (
      React.createElement(Chart, {
        legend: props.legend, 
        data: props.data, 
        margins: props.margins, 
        colors: props.colors, 
        width: props.width, height: props.height, 
        title: props.title}, 
        React.createElement("g", {transform: trans}, 
          React.createElement(Voronoi, {
            pubsub: pubsub, 
            data: allValues, 
            yScale: scales.yScale, 
            xScale: scales.xScale, 
            width: chartWidth, 
            height: chartHeight}
          ), 
          dataSeriesArray, 
          React.createElement(YAxis, {
            yAxisClassName: "scatter y axis", 
            yScale: scales.yScale, 
            yHideOrigin: props.yHideOrigin, 
            margins: props.margins, 
            yAxisTickCount: props.yAxisTickCount, 
            width: chartWidth, 
            height: chartHeight, 
            stroke: props.axesColor}
          ), 
          React.createElement(XAxis, {
            xAxisClassName: "scatter x axis", 
            strokeWidth: "1", 
            xHideOrigin: props.xHideOrigin, 
            xAxisTickInterval: props.xAxisTickInterval, 
            xScale: scales.xScale, 
            data: props.data, 
            margins: props.margins, 
            width: chartWidth, 
            height: chartHeight, 
            stroke: props.axesColor}
          )
        )
      )
    );
  }

});
